.. currentmodule:: fastdla

==========================
Computation of Lie closure
==========================

``lie_closure`` is the main function of the library.

.. autosummary::
   :toctree: ../generated
   :recursive:

   lie_closure
   orthogonalize
